Skip to content

__umul64hi

产品支持情况

  • Ascend 950PR/Ascend 950DT:支持
  • Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
  • Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
  • Atlas 200I/500 A2 推理产品:不支持
  • Atlas 推理系列产品AI Core:不支持
  • Atlas 推理系列产品Vector Core:不支持
  • Atlas 训练系列产品:不支持

功能说明

获取输入uint64类型数据x和y乘积的高64位。

函数原型

C++
unsigned long long __umul64hi(unsigned long long x, unsigned long long y)

参数说明

表1 参数说明

参数名输入/输出描述
x输入源操作数,乘数。
y输入源操作数,乘数。

返回值说明

输入uint64类型数据x和y乘积的高64位。

约束说明

需要包含的头文件

使用该接口需要包含"simt_api/device_functions.h"头文件。

C++
#include "simt_api/device_functions.h"

调用示例

  • SIMT编程场景:

    C++
    __global__ __launch_bounds__(1024) void KernelUmul64hi(unsigned long long* dst, unsigned long long* x, unsigned long long* y)
    {
        int idx = threadIdx.x + blockIdx.x * blockDim.x;
        dst[idx] = __umul64hi(x[idx], y[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    C++
    __simt_vf__ __launch_bounds__(1024) inline void KernelUmul64hi(__gm__ unsigned long long* dst, __gm__ unsigned long long* x, __gm__ unsigned long long* y)
    {
        int idx = threadIdx.x + blockIdx.x * blockDim.x;
        dst[idx] = __umul64hi(x[idx], y[idx]);
    }
    

免责声明:本站内容由 asc-devkit 仓 master 分支自动编译生成,属于持续开发版本,可能存在缺陷,仅供预览与参考。如需稳定及商用资料,请查阅官方 昇腾社区